import unittest

class Test(unittest.TestCase):

    def test_addition(self):
        self.assertEquals(self.test_obj.addition(1,2),3)

    def test_subtraction(self):
        self.assertEquals(self.test_obj.subtraction(1,2),-1)

    def test_multiplication(self):
        self.assertEquals(self.test_obj.multiplication(1,2),-1)





import setuptools

setuptools.setup(
    name='phoenixtesting',
    version='0.1.2',
    author='Prateek Joshi',
    author_email='prateekjoshi2013@gmail.com',
    description='Testing Package',
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    )